Learn R Programming

SentimentAnalysis (version 1.1-0)

preprocessCorpus: Default preprocessing of corpus

Description

Preprocess existing corpus of type Corpus according to default operations. This helper function groups all standard preprocessing steps such that the usage of the package is more convenient.

Usage

preprocessCorpus(corpus, language = "english", stemming = TRUE,
  verbose = FALSE, removeStopwords = TRUE)

Arguments

corpus
Corpus object which should be processed
language
Default language used for preprocessing (i.e. stop word removal and stemming)
stemming
Perform stemming (default: TRUE)
verbose
Print preprocessing status information
removeStopwords
Flag indicating whether to remove stopwords or not (default: yes)

Value

Object of Corpus